SET FOREIGN_KEY_CHECKS=0;
DROP TABLE IF EXISTS tdictionary;
DROP TABLE IF EXISTS ttranslationmapper;
DROP TABLE IF EXISTS tviewdeftable;
DROP TABLE IF EXISTS tviewdefcolumn;
DROP TABLE IF EXISTS tviewdefselectvalue;
SET FOREIGN_KEY_CHECKS=1;


CREATE TABLE tdictionary (
    id INT(15) NOT NULL AUTO_INCREMENT,
    keystr NVARCHAR(4096),
    lang NVARCHAR(8),
    translation NVARCHAR(4096),
    user_id INT(15) DEFAULT 1,
    status INT(15) DEFAULT 1,
    insdate TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    upddate TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY(id),
    FOREIGN KEY(user_id) REFERENCES cuser(id)
);


CREATE TABLE ttranslationmapper (
    id INT(15) NOT NULL AUTO_INCREMENT,
    parent NVARCHAR(64) DEFAULT NULL,
    parent_id INT(15) DEFAULT 1,
    columnname NVARCHAR(64) NOT NULL,
    dictionary_id INT(15) NOT NULL DEFAULT 1,
    user_id INT(15) DEFAULT 1,
    insdate TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    upddate TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY(id),
    FOREIGN KEY(user_id) REFERENCES cuser(id),
    FOREIGN KEY(dictionary_id) REFERENCES tdictionary(id)
);

CREATE TABLE tviewdeftable 
(
    id int(15) NOT NULL AUTO_INCREMENT, 
    tablename nvarchar(32), 
    description nvarchar(4096), 
    insdate timestamp DEFAULT CURRENT_TIMESTAMP, 
    upddate timestamp DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY(id)
);

CREATE TABLE tviewdefcolumn
(
    id int(15) NOT NULL AUTO_INCREMENT,
    tableid int(15) NOT NULL,
    columnname nvarchar(32), 
    pos int(15) NOT NULL,
    istextarea boolean NOT NULL,
    iseditable boolean NOT NULL,
    istranslated boolean NOT NULL,
    isselect boolean NOT NULL DEFAULT FALSE,
    type varchar(15) NOT NULL DEFAULT 'str',
    insdate timestamp DEFAULT CURRENT_TIMESTAMP, 
    upddate timestamp DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY(id),
    FOREIGN KEY(tableid) REFERENCES tviewdeftable(id) ON DELETE CASCADE ON UPDATE RESTRICT
);



CREATE TABLE tviewdefselectvalue (
    id int(15) NOT NULL AUTO_INCREMENT,
    columnid int(15) NOT NULL,
    pos int(15) NOT NULL DEFAULT 0,
    value varchar(31) NOT NULL,
    insdate timestamp DEFAULT CURRENT_TIMESTAMP, 
    upddate timestamp DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY(id),
    FOREIGN KEY(columnid) REFERENCES tviewdefcolumn(id) ON DELETE CASCADE ON UPDATE RESTRICT
);


INSERT INTO tviewdeftable (tablename, description) VALUES
('ccatalog', 'Contains catalog data. A catalog contains all products of a single KOCO supplier.'),
('cproductgroup', 'First hierarchy level of a catalog. Contains product groups.'),
('cfamily', 'Second hierarchy level of ccatalog, contained in cproductgroup. Contains product families.'),
('carticle', 'Third hierarchy level of ccatalog, contained in cfamily. Contains articles.'),
('capplication', 'Application information for a family.'),
('coption', 'Option information for a family.'),
('curl', 'Contains urls to additional information for articles, families and category trees.'),
('cspectable', 'Defines the specification table for articles or families.'),
('cspectableitem', 'Defines an item of a specification table.'),
('cbacklog', 'Contains backlog items.'),
('ccategorytree', 'Defines product categories in a tree structure.'),
('ccategorymapper', 'Maps product categories to families.'),
('cuser', 'Contains user information.'),
('cuserrole', 'Contains user role information.'),
('tdictionary', 'Dictionary with all translated phrases and paragraphs.'),
('ttranslationmapper', 'Maps field of a (table, column) pair to its translation in tdictionary.'),
('tviewdeftable', 'Defines and describes the tables that shall have a view-definition.'),
('tviewdefcolumn', 'Lists all columns of the tables defined in tviedeftable and sets their view, edit and translation properties.'),
('tviewdefselectvalues', 'List the values for the selectbox is a column in is of type "is_select" in tviewdefcolumn.'),
('cfiledata', 'Contains urls to additional information for articles, families, productgroups and category trees.');

INSERT INTO tviewdefcolumn (tableid, columnname, pos, istextarea, iseditable, istranslated, isselect, type) VALUES
-- ccatalog
(1, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(1, 'supplier', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(1, 'year', 2, FALSE, TRUE, FALSE, FALSE, 'int'),
(1, 'status', 3, FALSE, TRUE, FALSE, TRUE, 'int'),
(1, 'user_id', 4, FALSE, TRUE, FALSE, FALSE, 'int'),
(1, 'insdate', 5, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(1, 'upddate', 6, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cproductgroup
(2, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(2, 'product_group', 1, FALSE, TRUE, TRUE, FALSE, 'str'),
(2, 'description', 2, TRUE, TRUE, TRUE, FALSE, 'str'),
(2, 'image_url', 3, TRUE, TRUE, FALSE, TRUE, 'str'),
(2, 'supplier_site_url', 4, TRUE, TRUE, FALSE, FALSE, 'str'),
(2, 'catalog_id', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(2, 'status', 6, FALSE, TRUE, FALSE, TRUE, 'int'),
(2, 'user_id', 7, FALSE, TRUE, FALSE, FALSE, 'int'),
(2, 'order_priority', 8, FALSE, TRUE, FALSE, FALSE, 'int'),
(2, 'insdate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(2, 'upddate', 10, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cfamily
(3, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(3, 'family', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(3, 'type', 2, TRUE, TRUE, TRUE, FALSE, 'str'),
(3, 'description', 3, TRUE, TRUE, TRUE, FALSE, 'str'),
(3, 'short_description', 4, TRUE, TRUE, TRUE, FALSE, 'str'),
(3, 'product_group_id', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(3, 'status', 6, FALSE, TRUE, FALSE, TRUE, 'int'),
(3, 'user_id', 7, FALSE, TRUE, FALSE, FALSE, 'int'),
(3, 'insdate', 8, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(3, 'upddate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- carticle
(4, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(4, 'article', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(4, 'description', 2, TRUE, TRUE, TRUE, FALSE, 'str'),
(4, 'short_description', 3, TRUE, TRUE, TRUE, FALSE, 'str'),
(4, 'family_id', 4, FALSE, TRUE, FALSE, FALSE, 'int'),
(4, 'status', 5, FALSE, TRUE, FALSE, TRUE, 'int'),
(4, 'user_id', 6, FALSE, TRUE, FALSE, FALSE, 'int'),
(4, 'insdate', 7, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(4, 'upddate', 8, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- capplication
(5, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(5, 'application', 1, FALSE, TRUE, TRUE, FALSE, 'str'),
(5, 'family_id', 2, FALSE, TRUE, FALSE, FALSE, 'int'),
(5, 'user_id', 3, FALSE, TRUE, FALSE, FALSE, 'int'),
(5, 'insdate', 4, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(5, 'upddate', 5, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- coption
(6, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(6, 'option', 1, FALSE, TRUE, TRUE, FALSE, 'str'),
(6, 'type', 2, FALSE, TRUE, TRUE, TRUE, 'str'),
(6, 'category', 3, TRUE, TRUE, TRUE, FALSE, 'str'),
(6, 'family_id', 4, FALSE, TRUE, FALSE, FALSE, 'int'),
(6, 'user_id', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(6, 'insdate', 6, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(6, 'upddate', 7, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- curl
(7, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(7, 'type', 1, FALSE, TRUE, FALSE, TRUE, 'str'),
(7, 'supplier_url', 2, TRUE, TRUE, FALSE, FALSE, 'str'),
(7, 'KOCO_url', 3, TRUE, TRUE, FALSE, FALSE, 'str'),
(7, 'description', 4, TRUE, TRUE, TRUE, FALSE, 'str'),
(7, 'parent_id', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(7, 'parent', 6, FALSE, TRUE, FALSE, TRUE, 'str'),
(7, 'user_id', 7, FALSE, TRUE, FALSE, FALSE, 'int'),
(7, 'insdate', 8, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(7, 'upddate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cspectable
(8, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(8, 'name', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(8, 'type', 2, FALSE, TRUE, FALSE, TRUE, 'str'),
(8, 'has_unit', 3, FALSE, TRUE, FALSE, TRUE, 'bool'),
(8, 'parent', 4, FALSE, TRUE, FALSE, TRUE, 'str'),
(8, 'parent_id', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(8, 'user_id', 6, FALSE, TRUE, FALSE, FALSE, 'int'),
(8, 'insdate', 7, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(8, 'upddate', 8, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cspectableitem
(9, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(9, 'pos', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(9, 'name', 2, FALSE, TRUE, TRUE, FALSE, 'str'),
(9, 'unit', 3, FALSE, TRUE, FALSE, FALSE, 'str'),
(9, 'value', 4, FALSE, TRUE, FALSE, FALSE, 'str'),
(9, 'min_value', 5, FALSE, TRUE, FALSE, FALSE, 'str'),
(9, 'max_value', 6, FALSE, TRUE, FALSE, FALSE, 'str'),
(9, 'spec_table_id', 7, FALSE, TRUE, FALSE, FALSE, 'int'),
(9, 'user_id', 8, FALSE, TRUE, FALSE, FALSE, 'int'),
(9, 'insdate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(9, 'upddate', 10, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cbacklog
(10, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(10, 'backlog_text', 1, TRUE, TRUE, FALSE, FALSE, 'str'),
(10, 'status', 2, FALSE, TRUE, FALSE, TRUE, 'int'),
(10, 'user_id', 3, FALSE, TRUE, FALSE, FALSE, 'int'),
(10, 'insdate', 4, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(10, 'upddate', 5, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- ccategorytree
(11, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(11, 'category', 1, FALSE, TRUE, TRUE, FALSE, 'str'),
(11, 'description', 2, TRUE, TRUE, TRUE, FALSE, 'str'),
(11, 'export_target', 3, FALSE, TRUE, FALSE, TRUE, 'str'),
(11, 'parent_id', 4, FALSE, TRUE, FALSE, FALSE, 'int'),
(11, 'pos', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(11, 'user_id', 6, FALSE, TRUE, FALSE, FALSE, 'int'),
(11, 'insdate', 7, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(11, 'upddate', 8, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- ccategorymapper
(12, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(12, 'category_id', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(12, 'family_id', 2, FALSE, TRUE, FALSE, FALSE, 'int'),
(12, 'user_id', 3, FALSE, TRUE, FALSE, FALSE, 'int'),
(12, 'insdate', 4, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(12, 'upddate', 5, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cuser
(13, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(13, 'name', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(13, 'first_name', 2, FALSE, TRUE, FALSE, FALSE, 'str'),
(13, 'last_name', 3, FALSE, TRUE, FALSE, FALSE, 'str'),
(13, 'email', 4, FALSE, TRUE, FALSE, FALSE, 'str'),
(13, 'password', 5, FALSE, FALSE, FALSE, FALSE, 'bytes'),
(13, 'role_id', 6, FALSE, TRUE, FALSE, TRUE, 'int'),
(13, 'user_id', 7, FALSE, TRUE, FALSE, FALSE, 'int'),
(13, 'insdate', 8, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(13, 'upddate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cuserrole
(14, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(14, 'role', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(14, 'description', 2, TRUE, TRUE, FALSE, FALSE, 'str'),
(14, 'user_id', 3, FALSE, TRUE, FALSE, FALSE, 'int'),
(14, 'insdate', 4, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(14, 'upddate', 5, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- tdictionary
(15, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(15, 'keystr', 1, TRUE, TRUE, FALSE, FALSE, 'str'),
(15, 'lang', 2, FALSE, TRUE, FALSE, TRUE, 'str'),
(15, 'translation', 3, TRUE, TRUE, FALSE, FALSE, 'str'),
(15, 'user_id', 4, FALSE, TRUE, FALSE, FALSE, 'int'),
(15, 'status', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(15, 'insdate', 6, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(15, 'upddate', 7, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- translationmapper
(16, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(16, 'parent', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(16, 'parent_id', 2, FALSE, TRUE, FALSE, FALSE, 'int'),
(16, 'columnname', 3, FALSE, TRUE, FALSE, FALSE, 'str'),
(16, 'dictionary_id', 4, FALSE, TRUE, FALSE, FALSE, 'int'),
(16, 'user_id', 5, FALSE, TRUE, FALSE, FALSE, 'int'),
(16, 'insdate', 6, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(16, 'upddate', 7, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- tviewdeftable
(17, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(17, 'tablename', 1, FALSE, TRUE, FALSE, FALSE, 'str'),
(17, 'description', 2, TRUE, TRUE, FALSE, FALSE, 'str'),
(17, 'insdate', 3, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(17, 'upddate', 4, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- tviewdefcolumn
(18, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(18, 'tableid', 1, FALSE, TRUE, FALSE, FALSE, 'int'),
(18, 'columnname', 2, FALSE, TRUE, FALSE, FALSE, 'str'),
(18, 'pos', 3, FALSE, TRUE, FALSE, FALSE, 'str'),
(18, 'istextarea', 4, FALSE, TRUE, FALSE, TRUE, 'bool'),
(18, 'iseditable', 5, FALSE, TRUE, FALSE, TRUE, 'bool'),
(18, 'istranslated', 6, FALSE, TRUE, FALSE, TRUE, 'bool'),
(18, 'isselect', 7, FALSE, TRUE, FALSE, TRUE, 'bool'),
(18, 'type', 8, FALSE, TRUE, FALSE, TRUE, 'str'),
(18, 'insdate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(18, 'upddate', 10, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- tviewdefselectvalue
(19, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(19, 'columnid', 1, FALSE, TRUE, FALSE, FALSE, 'int'),
(19, 'pos', 3, FALSE, TRUE, FALSE, FALSE, 'str'),
(19, 'value', 3, FALSE, TRUE, FALSE, FALSE, 'str'),
(19, 'insdate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(19, 'upddate', 10, FALSE, FALSE, FALSE, FALSE, 'datetime'),
-- cfiledata
(20, 'id', 0, FALSE, FALSE, FALSE, FALSE, 'int'),
(20, 'documenttype', 1, FALSE, TRUE, FALSE, TRUE, 'str'),
(20, 'description_json', 2, TRUE, TRUE, FALSE, FALSE, 'str'),
(20, 'oldfilename', 3, FALSE, TRUE, FALSE, FALSE, 'str'),
(20, 'entity_id', 4, FALSE, TRUE, FALSE, FALSE, 'int'),
(20, 'entity_type', 5, FALSE, TRUE, FALSE, FALSE, 'str'),
(20, 'mimetype', 6, FALSE, TRUE, FALSE, FALSE, 'str'),
(20, 'blake2shash', 7, FALSE, TRUE, FALSE, FALSE, 'str'),
(20, 'user_id', 8, FALSE, TRUE, FALSE, FALSE, 'int'),
(20, 'insdate', 9, FALSE, FALSE, FALSE, FALSE, 'datetime'),
(20, 'upddate', 10, FALSE, FALSE, FALSE, FALSE, 'datetime');

INSERT INTO tviewdefselectvalue (columnid, pos, value) VALUES
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ccatalog' AND columnname='status'), 1, '1'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ccatalog' AND columnname='status'), 2, '2'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ccatalog' AND columnname='status'), 3, '3'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cproductgroup' AND columnname='status'), 1, '1'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cproductgroup' AND columnname='status'), 2, '2'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cproductgroup' AND columnname='status'), 3, '3'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfamily' AND columnname='status'), 1, '1'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfamily' AND columnname='status'), 2, '2'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfamily' AND columnname='status'), 3, '3'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='carticle' AND columnname='status'), 1, '1'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='carticle' AND columnname='status'), 2, '2'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='carticle' AND columnname='status'), 3, '3'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='coption' AND columnname='type'), 1, 'Option'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='coption' AND columnname='type'), 2, 'Feature'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 1, 'photo'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 2, 'supplier_site'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 3, 'drawing'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 4, 'manual'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 5, 'software'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 6, 'firmware'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 7, '3D model'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 8, 'certificate'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 9, 'datasheet'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 10, 'catalog'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 11, 'speed_curves'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 12, 'screw_option'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='type'), 13, 'accessory'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='parent'), 1, 'article'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='parent'), 2, 'family'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='curl' AND columnname='parent'), 3, 'categorytree'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='type'), 1, 'overview'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='type'), 2, 'free'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='type'), 3, 'singlecol'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='type'), 4, 'multicol'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='has_unit'), 1, 'True'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='has_unit'), 2, 'False'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='parent'), 1, 'article'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cspectable' AND columnname='parent'), 2, 'family'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cbacklog' AND columnname='status'), 1, '1'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cbacklog' AND columnname='status'), 2, '2'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cbacklog' AND columnname='status'), 3, '3'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cuser' AND columnname='role_id'), 1, '1'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cuser' AND columnname='role_id'), 2, '2'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cuser' AND columnname='role_id'), 3, '3'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tdictionary' AND columnname='lang'), 1, 'de'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tdictionary' AND columnname='lang'), 2, 'en'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tdictionary' AND columnname='status'), 1, '1'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tdictionary' AND columnname='status'), 2, '2'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tdictionary' AND columnname='status'), 3, '3'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 1, 'ccatalog'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 2, 'cproductgroup'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 3, 'cfamily'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 4, 'carticle'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 5, 'cspectable'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 6, 'cspectableitem'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 7, 'coption'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 8, 'capplication'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ttranslationmapper' AND columnname='parent'), 9, 'curl'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='type'), 1, 'str'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='type'), 2, 'int'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='type'), 3, 'bool'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='istextarea'), 1, 'True'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='istextarea'), 2, 'False'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='iseditable'), 1, 'True'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='iseditable'), 2, 'False'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='istranslated'), 1, 'True'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='istranslated'), 2, 'False'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='isselect'), 1, 'True'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='tviewdefcolumn' AND columnname='isselect'), 2, 'False'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ccategorytree' AND columnname='export_target'), 1, 'KOMO WP'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='ccategorytree' AND columnname='export_target'), 2, 'KOAM WP'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 1, 'photo'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 2, 'drawing'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 3, 'datasheet'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 4, 'step'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 5, '2D drawings'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 6, '3D drawings'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 7, '3D models'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 8, 'manual'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 9, 'software'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 10, 'firmware'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 11, 'certifications'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 12, 'catalog'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 13, 'accessories'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 14, 'speed_curves'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 15, 'screw_option'),
((SELECT tdc.id FROM tviewdefcolumn tdc JOIN tviewdeftable tdt ON tdc.tableid=tdt.id WHERE tdt.tablename='cfiledata' AND columnname='documenttype'), 16, 'supplier_site');






